jacinle.utils.registry
======================

.. automodule:: jacinle.utils.registry

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      CallbackRegistry
      DefaultRegistry
      EventRegistry
      EventRegistryGroup
      LockRegistry
      Registry
      RegistryGroup
      SimpleEventRegistry
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      register_event
      subclass_registry_point
      trigger_event
   
   

   
   
   








.. rubric:: Class CallbackRegistry
.. autoclass:: CallbackRegistry
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class DefaultRegistry
.. autoclass:: DefaultRegistry
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class EventRegistry
.. autoclass:: EventRegistry
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class EventRegistryGroup
.. autoclass:: EventRegistryGroup
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class LockRegistry
.. autoclass:: LockRegistry
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Registry
.. autoclass:: Registry
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class RegistryGroup
.. autoclass:: RegistryGroup
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class SimpleEventRegistry
.. autoclass:: SimpleEventRegistry
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: register_event

.. autofunction:: subclass_registry_point

.. autofunction:: trigger_event


